# Consulta gob

Un paquete de Python que permite obtener información de manera rápida y automatizable

## Como usar

```python
import consulta-gob
consulta-gob.consulta_CURP("CURP A CONSULTAR", "TU TOKEN DE API")
```
